@@ -33,7 +33,7 @@ read_mlx_ind_est <- function(path, x, ...) {
     ds[, c("ID", "OCC") := tstrsplit(ID, "#")       ][
       ,
       c("ID", "OCC") := list(as.integer(ID), as.integer(OCC))
-    ]
+      ]
   }
   if (!is.null(occ) && occ %in% names(ds)) setnames(ds, occ, "OCC")
   if (identical(names(ds), "ID")) {
@@ -60,21 +60,24 @@ read_mlx18_ind_est <- function(path, x, ...) {
 #' @param strats \emph{[Optional]}\code{character} extra stratification variables
 #' @param occ \emph{[Optional]}\code{character} inter individual occasion variables
 #' @param endpoint \code{integer}  null in case of a single endpoint otherwise the index of endpoints.
+#' @param id \code{character} the name of identifier variable used in the input modelling file.
+#' @param time \code{character} the name of time variable used in the input modelling file
 
 #'
 #' @return data.table well formatted containing modelling input data
 #'
-read_input <- function(ipath, dv, dvid, cats = "", conts="", strats="", occ="", endpoint=NULL) {
+read_input <- function(ipath, dv, dvid, cats = "", conts="", strats="", occ="", 
+                       endpoint=NULL, id=NULL, time=NULL) {
   TIME <- EVID <- MDV <- y <- DV <- NULL
   xx <- pmx_fread(ipath)
-
+  
   if (all(c("MDV", "EVID") %in% toupper(names(xx)))) {
     setnames(xx, grep("^mdv$", names(xx), ignore.case = TRUE, value = TRUE), "MDV")
     setnames(xx, grep("^evid$", names(xx), ignore.case = TRUE, value = TRUE), "EVID")
     xx <- xx[!(EVID == 1 & MDV == 1)]
   }
-
-
+  
+  
   if (!is.null(endpoint)) {
     if (!is.null(dvid) && dvid %in% names(xx)) {
       rr <- dvid
@@ -86,7 +89,7 @@ read_input <- function(ipath, dv, dvid, cats = "", conts="", strats="", occ="",
     } else {
       msg <- sprintf("ggPMX can not filter by endpoint %s\n", endpoint$code)
       msg <- paste(msg, sprintf("%s is not a valid column in the observation data set", dvid))
-
+      
       stop(msg)
     }
   }
@@ -97,22 +100,25 @@ read_input <- function(ipath, dv, dvid, cats = "", conts="", strats="", occ="",
       if (length(ends) > 1) {
         msg <- sprintf("Observation data contains multiple endpoints %s. \n ", paste(ends, collapse = " ; "))
         msg <- paste(msg, "Please select a single endpoint to continue.")
-
+        
         stop(msg)
       }
     }
   }
-
-
-
-
-  id_col <- grep("^id$", names(xx), ignore.case = TRUE, value = TRUE)
-  if (length(id_col) == 0) {
-    id_col <- names(xx)[1]
-    message("input do not contain ID variable: ggPMX use first input variable ", id_col)
+  
+  
+  
+  if(!is.null(id)  && id %in% names(xx)){
+    setnames(xx, id_col, "ID")
+  } else{
+    id_col <- grep("^id$", names(xx), ignore.case = TRUE, value = TRUE)
+    if (length(id_col) == 0) {
+      id_col <- names(xx)[1]
+      message("input do not contain ID variable: ggPMX use first input variable ", id_col)
+    }
+    setnames(xx, id_col, "ID")
   }
-  setnames(xx, id_col, "ID")
-
+  
   if (dv %in% names(xx)) {
     if (dv == "dv") {
       xx[, DV := dv]
@@ -127,19 +133,23 @@ read_input <- function(ipath, dv, dvid, cats = "", conts="", strats="", occ="",
                         suggested names are : %s", dv, dv.names)
     stop(err.msg)
   }
-
+  
   if (nzchar(occ) && occ %in% names(xx)) {
     setnames(xx, occ, "OCC")
   }
   ## round time column for further merge
-  setnames(xx, grep("^time$", names(xx), ignore.case = TRUE, value = TRUE), "TIME")
+  if(!is.null(time)  && time %in% names(xx)){
+    setnames(xx, time, "TIME")
+  } else{
+    setnames(xx, grep("^time$", names(xx), ignore.case = TRUE, value = TRUE), "TIME")
+  }
   xx[, TIME := round(TIME, 4)]
-
-
-
-
-
-
+  
+  
+  
+  
+  
+  
   covariates <- unique(c(cats, conts))
   if (length(covariates[covariates != ""])) {
     covariates <- covariates[covariates != ""]
@@ -162,7 +172,7 @@ read_input <- function(ipath, dv, dvid, cats = "", conts="", strats="", occ="",
     conts <- conts[conts != ""]
     xx[, (conts) := lapply(.SD, as.numeric), .SDcols = conts]
   }
-
+  
   xx
 }
 
@@ -268,11 +278,11 @@ read_mlx_pred <- function(path, x, ...) {
     names.nn <- c(names.nn, "OCC")
   }
   res <- setnames(xx[, nn, with = FALSE], names.nn)
-
+  
   ## select columns
-
-
-
+  
+  
+  
   res
 }
 
@@ -281,7 +291,7 @@ read_mlx18_res <- function(path, x, ...) {
   if (exists("subfolder", x)) {
     path <- file.path(dirname(path), x$subfolder)
   }
-
+  
   res_file <- file.path(path, x$file)
   file_path <- if (!file.exists(res_file)) {
     ffiles <- list.files(path, pattern = x$pattern, full.names = TRUE)
@@ -303,7 +313,7 @@ read_mlx18_res <- function(path, x, ...) {
     message(sub(".txt", "", x[["file"]]), " file do not exist")
     return(NULL)
   }
-
+  
   ds <- pmx_fread(file_path)
   ids <- match(tolower(names(x[["names"]])), tolower(names(ds)))
   new_vars <- names(x[["names"]])
@@ -321,8 +331,8 @@ read_mlx18_pred <- function(path, x, ...) {
       finegrid_file
     }
   }
-
-
+  
+  
   ds <- read_mlx_pred(path = path, x = x, ...)
   if (exists("residuals", x)) {
     x$residuals$endpoint <- x$endpoint
@@ -383,14 +393,14 @@ load_data_set <- function(x, path, sys, ...) {
       }
     }
   }
-
+  
   if (!exists_file && sys != "mlx18") {
     cat(x[["label"]], " file do not exist. \n")
     return(NULL)
   }
-
-
-
+  
+  
+  
   if (exists("reader", x)) {
     return(do.call(x[["reader"]], list(fpath, x, ...)))
   }
@@ -426,7 +436,7 @@ load_source <- function(sys, path, dconf, ...) {
     x$name <- nn
     load_data_set(x, path = path, sys = sys, ...)
   }, dconf, names(dconf))
-
-
+  
+  
   dxs
 }
